@@ -1,23 +1,27 @@
-#! /usr/bin/env python
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 
-## Copyright 1999-2007 by LivingLogic AG, Bayreuth/Germany.
-## Copyright 1999-2007 by Walter Drwald
+## Copyright 1999-2009 by LivingLogic AG, Bayreuth/Germany
+## Copyright 1999-2009 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
-## See xist/__init__.py for the license
+## See ll/__init__.py for the license
 
 
 """
-<par>An &xist; namespace that contains all the character entities defined in &html;.</par>
+An XIST namespace that contains all the character entities defined in HTML.
 """
 
-__version__ = "$Revision: 1.1.2.1 $".split()[1]
-# $Source: /data/cvsroot/LivingLogic/Python/xist/src/ll/xist/ns/chars.py,v $
 
 from ll.xist import xsc
 
+
+__docformat__ = "reStructuredText"
+
+
+xmlns = "http://xmlns.livinglogic.de/xist/ns/chars"
+
+
 # Latin 1 characters
 class nbsp(xsc.CharRef): "no-break space = non-breaking space, U+00A0 ISOnum"; codepoint = 160
 class iexcl(xsc.CharRef): "inverted exclamation mark, U+00A1 ISOnum"; codepoint = 161
@@ -292,9 +296,3 @@ class spades(xsc.CharRef): "black spade suit, U+2660 ISOpub"; codepoint = 9824
 class clubs(xsc.CharRef): "black club suit = shamrock, U+2663 ISOpub"; codepoint = 9827
 class hearts(xsc.CharRef): "black heart suit = valentine, U+2665 ISOpub"; codepoint = 9829
 class diams(xsc.CharRef): "black diamond suit, U+2666 ISOpub"; codepoint = 9830
-
-
-class __ns__(xsc.Namespace):
-	xmlname = "chars"
-	xmlurl = "http://xmlns.livinglogic.de/xist/ns/chars"
-__ns__.makemod(vars())
